TypedOptions

Struct TypedOptions 

pub struct TypedOptions<SupportsMove = Bool<true>, ListFanout = Usize<12>, ChunkSize = Usize<32>>(/* private fields */);
Like Options, but uses types instead of const parameters.

Options is actually a type alias of this type.