Id

Trait Id 

pub trait Id: Clone + Ord { }
The trait that ID types must implement.

This is effectively an alias of Clone + Ord; it is automatically implemented for all types that implement those traits.

Although not strictly required, ID types should be small in size and cheap to clone (Copy is strongly encouraged).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T: Clone + Ord> Id for T